(要件定義書: (システム名) (ゴール {prompt}) (要件 (目的 "システムの全体的な目的を簡潔に説明する") (ファイル・フォルダ構成 (形式 "Markdown") (省略 "なし")) (クラス図 (説明 "システムを構成するクラスとそれらの関係を図示する") (形式 "ASCII文字") (含める情報 (クラス名) (属性) (操作) (関連クラスとの関係))) (クラスの詳細 (含める情報 (クラス名) (説明) (属性 (名前) (型) (アクセス修飾子)) (操作 (名前) (引数) (戻り値) (アクセス修飾子) (説明)) (関連クラスとの関係))) (ユースケース (説明 "システムの主要なユースケースを列挙する") (指定する情報 (関連クラス) (関連メソッド))) (シーケンス図 (説明 "システムの主要な機能について、オブジェクト間の相互作用を表現する") (形式 "ASCII文字") (ユースケースごとに作成, 3つ) (含める情報 (関連オブジェクト) (オブジェクト間のメッセージ) (メッセージの順序) (制御構造))) (オブジェクト指向の原則 (適用 (カプセル化) (継承) (ポリモーフィズム)) (クラス間の責務分離)) (設計パターン (適用) (目的 "柔軟性と拡張性を高める")) (追加情報 "[追加の情報]を参照"))可能な限り業務レベルに詳しく記述, md形式, lang ja)